==> hydrogen_0.8.2.orig.tar.gz: hydrogen-0.8.2/hydrogen_gui/SongPropertiesDialog.cpp <==
/*
 * Hydrogen
 * Copyright(c) 2002-2004 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://hydrogen.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: SongPropertiesDialog.cpp,v 1.8 2004/01/26 11:17:48 comix Exp $
 *
 */

#include "SongPropertiesDialog.h"
#include "lib/Song.h"

/**
 * Constructor
 */
SongPropertiesDialog::SongPropertiesDialog(QWidget* parent) : SongPropertiesDialog_UI(parent) {
	setCaption( trUtf8( "Song properties" ) );
	setIcon( QPixmap( QString(IMG_PATH) + QString( "/img/icon32.png") ) );

	Song *song = (HydrogenApp::getInstance())->getSong();
	songNameTxt->setText( trUtf8( (song->getName()).c_str() ) );

	authorTxt->setText( trUtf8( (song->getAuthor()).c_str() ) );
	notesTxt->setText( trUtf8( (song->getNotes()).c_str() ) );

}




/**
 * Destructor
 */
SongPropertiesDialog::~SongPropertiesDialog() {
}



/**
 *
 */
void SongPropertiesDialog::cancelBtnClicked() {
	reject();
}



/**
 *
 */
void SongPropertiesDialog::okBtnClicked() {
	Song *song = (HydrogenApp::getInstance())->getSong();
	
	song->setName(songNameTxt->text().latin1());
	song->setAuthor(authorTxt->text().latin1());
	song->setNotes(notesTxt->text().latin1());
	accept();
}



/** ??? */
void SongPropertiesDialog::languageChange() {
}

==> hydrogen_0.9.1.orig.tar.gz: hydrogen-0.9.1/hydrogen_gui/SongPropertiesDialog.cpp <==
/*
 * Hydrogen
 * Copyright(c) 2002-2004 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://hydrogen.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: SongPropertiesDialog.cpp,v 1.10 2004/04/26 08:10:54 comix Exp $
 *
 */

#include "SongPropertiesDialog.h"
#include "lib/Song.h"

#include "qlineedit.h"
#include "qtextedit.h"


SongPropertiesDialog::SongPropertiesDialog(QWidget* parent) : SongPropertiesDialog_UI(parent) {
	setCaption( trUtf8( "Song properties" ) );
	setIcon( QPixmap( QString(IMG_PATH) + QString( "/img/icon32.png") ) );

	Song *song = (HydrogenApp::getInstance())->getSong();
	songNameTxt->setText( trUtf8( (song->getName()).c_str() ) );

	authorTxt->setText( trUtf8( (song->getAuthor()).c_str() ) );
	notesTxt->setText( trUtf8( (song->getNotes()).c_str() ) );

}



SongPropertiesDialog::~SongPropertiesDialog() {
}



void SongPropertiesDialog::cancelBtnClicked() {
	reject();
}



void SongPropertiesDialog::okBtnClicked() {
	Song *song = (HydrogenApp::getInstance())->getSong();
	
	song->setName(songNameTxt->text().latin1());
	song->setAuthor(authorTxt->text().latin1());
	song->setNotes(notesTxt->text().latin1());
	accept();
}
